@@ -23,15 +23,15 @@ def create_form(items, *, context, form_class=forms.Form, form_kwargs):
         if hasattr(item, "get_fields")
     }
     all_fields = reduce(lambda a, b: {**a, **b}, item_fields.values(), {})
-    all_keys = set(all_fields)
+    all_names = set(all_fields)
 
     form = type("Form", (FormMixin, form_class), all_fields)(**form_kwargs)
     form._f3f_item_fields = {
         **{
-            item: {key: form[key] for key in fields}
+            item: {name: form[name] for name in fields}
             for item, fields in item_fields.items()
         },
-        **{None: {key: form[key] for key in form.fields if key not in all_keys}},
+        **{None: {name: form[name] for name in form.fields if name not in all_names}},
     }
 
     return form
